# GetPaymentRunDataTransactionElementResponseType

The type of the current transaction. 

## Enum

* `PAYMENT` (value: `'Payment'`)

* `CREDITMEMO` (value: `'CreditMemo'`)

* `UNAPPLIEDPAYMENT` (value: `'UnappliedPayment'`)

* `CREDITBALANCEADJUSTMENT` (value: `'CreditBalanceAdjustment'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


